.. image:: https://github.com/EddLabs.png
   :width: 72px

Eddington
=========

.. image:: https://img.shields.io/pypi/pyversions/eddington.svg
   :target: https://pypi.python.org/pypi/eddington
   :alt: Python Versions

.. image:: https://img.shields.io/pypi/v/eddington.svg
   :target: https://pypi.python.org/pypi/eddington
   :alt: PyPI Version

.. image:: https://img.shields.io/pypi/status/eddington.svg
   :target: https://pypi.python.org/pypi/eddington
   :alt: Maturity

.. image:: https://img.shields.io/pypi/l/eddington.svg
   :target: https://github.com/EddLabs/eddington/blob/master/LICENSE
   :alt: License

.. image:: https://github.com/EddLabs/eddington/workflows/CI/badge.svg?branch=master
   :target: https://github.com/EddLabs/eddington/actions
   :alt: Build Status

.. image:: https://badges.gitter.im/EddLabs/developers.svg
   :target: https://gitter.im/EddLabs/developers
   :alt: Chat on Gitter

*Eddington* is a user-friendly data fitting platform for common uses, based on
open-source libraries such as *numpy*, *scipy*, and *matplotlib*.
*Eddington* can be integrated with python code as a library, can be used as a CLI and
has an easy to use GUI.

Installation
------------

In order to install eddington use::

   pip install eddington

Documentation
-------------

Documentation for Eddington can be found on `Read The Docs`_.

Community
---------

You can talk to the community through the `EddLabs/developers`_ channel on Gitter.

Contributing
------------

If you experience problems with Eddington, `log them on GitHub`_.

If you want to contribute code, please `fork the code`_ and `submit a pull request`_.

.. _Read The Docs: https://eddington.readthedocs.io
.. _EddLabs/developers: https://gitter.im/EddLabs/developers
.. _log them on Github: https://github.com/EddLabs/eddington/issues
.. _fork the code: https://github.com/EddLabs/eddington
.. _submit a pull request: https://github.com/EddLabs/eddington/pulls
